==> cloudfront-1.104.0-sources.jar: software/amazon/awscdk/services/cloudfront/AllowedMethods.java <==
package software.amazon.awscdk.services.cloudfront;

/**
 * The HTTP methods that the Behavior will accept requests on.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-05-14T22:40:15.975Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudfront.$Module.class, fqn = "@aws-cdk/aws-cloudfront.AllowedMethods")
public class AllowedMethods extends software.amazon.jsii.JsiiObject {

    protected AllowedMethods(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected AllowedMethods(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        ALLOW_ALL = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudfront.AllowedMethods.class, "ALLOW_ALL", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.AllowedMethods.class));
        ALLOW_GET_HEAD = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudfront.AllowedMethods.class, "ALLOW_GET_HEAD", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.AllowedMethods.class));
        ALLOW_GET_HEAD_OPTIONS = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudfront.AllowedMethods.class, "ALLOW_GET_HEAD_OPTIONS", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.AllowedMethods.class));
    }

    /**
     * All supported HTTP methods.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.cloudfront.AllowedMethods ALLOW_ALL;

    /**
     * HEAD and GET.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.cloudfront.AllowedMethods ALLOW_GET_HEAD;

    /**
     * HEAD, GET, and OPTIONS.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.cloudfront.AllowedMethods ALLOW_GET_HEAD_OPTIONS;

    /**
     * HTTP methods supported.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getMethods() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "methods", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }
}

==> cloudfront-1.173.0-sources.jar: software/amazon/awscdk/services/cloudfront/AllowedMethods.java <==
package software.amazon.awscdk.services.cloudfront;

/**
 * The HTTP methods that the Behavior will accept requests on.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // Create a Distribution with configured HTTP methods and viewer protocol policy of the cache.
 * Bucket myBucket;
 * Distribution myWebDistribution = Distribution.Builder.create(this, "myDist")
 *         .defaultBehavior(BehaviorOptions.builder()
 *                 .origin(new S3Origin(myBucket))
 *                 .allowedMethods(AllowedMethods.ALLOW_ALL)
 *                 .viewerProtocolPolicy(ViewerProtocolPolicy.REDIRECT_TO_HTTPS)
 *                 .build())
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:32.726Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudfront.$Module.class, fqn = "@aws-cdk/aws-cloudfront.AllowedMethods")
public class AllowedMethods extends software.amazon.jsii.JsiiObject {

    protected AllowedMethods(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected AllowedMethods(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        ALLOW_ALL = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudfront.AllowedMethods.class, "ALLOW_ALL", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.AllowedMethods.class));
        ALLOW_GET_HEAD = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudfront.AllowedMethods.class, "ALLOW_GET_HEAD", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.AllowedMethods.class));
        ALLOW_GET_HEAD_OPTIONS = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudfront.AllowedMethods.class, "ALLOW_GET_HEAD_OPTIONS", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.AllowedMethods.class));
    }

    /**
     * All supported HTTP methods.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.cloudfront.AllowedMethods ALLOW_ALL;

    /**
     * HEAD and GET.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.cloudfront.AllowedMethods ALLOW_GET_HEAD;

    /**
     * HEAD, GET, and OPTIONS.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.cloudfront.AllowedMethods ALLOW_GET_HEAD_OPTIONS;

    /**
     * HTTP methods supported.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getMethods() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "methods", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }
}
